@@ -85,11 +85,30 @@ class ZIDS_PLModel(pl.LightningModule):
 
     def __init__(self, model_config=None, metrics_config=None, trainer_config=None):
         super().__init__()
+        self.train_accuracy = None
+        self.val_accuracy = None
+        self.test_accuracy = None
+
+        self.train_precision = None
+        self.val_precision = None
+        self.test_precision = None
+
+        self.train_recall = None
+        self.val_recall = None
+        self.test_recall = None
+
+        self.train_f1 = None
+        self.val_f1 = None
+        self.test_f1 = None
+
+        self.train_confusion_matrix = None
+        self.val_confusion_matrix = None
+        self.test_confusion_matrix = None
 
         self.model_config = model_config
         self.trainer_config = trainer_config
         self.metrics = metrics_config
-        self.loss_function = self.model_config['loss_function']
+        self.loss_function = self.model_config.get('loss_function', None)
         self.test_results = None
 
     def configure_optimizers(self):
