@@ -305,7 +305,7 @@ class ZIDSBatchHelper:
         """
 
         # Define some job parameters
-        stage_dir = f"batch_files/workflows/{self.wf_name}_workflow/stages/{stage_name}"
+        stage_dir = f"batch_files/stages/{stage_name}"
         file_name = f"{self.project_name}_{self.wf_name}.zip"
 
         spark_properties = self.config["spark_properties"]
