@@ -9,7 +9,7 @@ dataset = json.loads(sys.argv[3])
 tag_name = sys.argv[4]
 
 t = tokenGenerator()
-jwtToken = t.generateToken(env.upper() + '_Conf')
+jwtToken = t.generateToken(env.upper() + '_DSP_Conf')
 
 data = {
     "model_type_id": model['id'],
