@@ -74,13 +74,19 @@ def extract_host_and_service_account(request):
 
 
 class OutputLogger:
-    def __init__(self, data, host, service_account, endpoint) -> None:
+    def __init__(self, endpoint) -> None:
+        self.data = None
+        self.host = None
+        self.service_account = None
+        self.endpoint = endpoint
+
+    def save_request_info(self, data, host, service_account) -> None:
         self.data = data
         self.host = host
         self.service_account = service_account
-        self.endpoint = endpoint
 
     def log_output(self, output, retrieve_type='', pipeline_timing=None, predictable_object_count=None):
+
         extra_info = dict(input=self.data, output=output, from_host=self.host,
                           from_service_account=self.service_account)
         if pipeline_timing:
@@ -120,6 +126,7 @@ app.add_middleware(
 ## To enable caching change cache_type to Cache.Type.REDIS
 cache_type = Cache.Type.NONE
 cache = CacheProvider.get_cache(cache_type)
+cache_facade = CacheFacade(cache, cache_type)
 
 
 @app.on_event("startup")
@@ -131,9 +138,9 @@ def run_cache_timer() -> None:
 
 ## Initialized a pipeline for /predict /parse endpoints.
 pipeline = generatedProjectNamePipeline()
-# from server.pool import InstancePool
-# pipelines = [generatedProjectNamePipeline() for i in range(3)]
-# app.pipelines = InstancePool(pipelines)
+
+# Initialize logger classes
+predict_logger = OutputLogger('predict')
 
 
 @app.post('/predict', dependencies=[Depends(get_token_header)])
@@ -151,17 +158,20 @@ def predict(body: generatedProjectNameInputs, request: Request) -> List[generate
     """
     host, service_account = extract_host_and_service_account(request)
     data = body.dict()
-    cache_facade = CacheFacade(cache, cache_type, data, host, service_account)
-    output_logger = OutputLogger(data, host, service_account, 'predict')
+    cache_facade.get_request_data(data, host, service_account)
+    predict_logger.save_request_info(data, host, service_account)
+
     output = cache_facade.get('--- REPLACE WITH KEYWORD FOR FINDING KEYS INSIDE THE INPUT (data) ---')
     if len(output) > 0:
-        output_logger.log_output(output, 'cache')
+        predict_logger.log_output(output, 'cache')
         return output
     try:
         tic = time.perf_counter()
         output: List[generatedProjectNameOutputs] = pipeline.execute(**data)  # call model here
         pipeline_timing = f"{time.perf_counter() - tic:0.6f}"
-        output_logger.log_output(output, pipeline_timing=pipeline_timing, predictable_object_count=len(output))
+        predict_logger.log_output(output,
+                                  pipeline_timing=pipeline_timing,
+                                  predictable_object_count=len(output) if isinstance(output, list) else 1)
         cache_facade.set(output)
     except Exception as ex:
         output = {'error': {'request': str(ex)}}
